changeset 20635:3bdf83b27946

(Fcall_interactively): Allocate string by bytes. Use message_with_string.
author Richard M. Stallman <rms@gnu.org>
date Fri, 09 Jan 1998 23:33:09 +0000
parents 8e7e791c49ca
children 5ab6701a2b4b
files src/callint.c
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/callint.c	Fri Jan 09 23:28:38 1998 +0000
+++ b/src/callint.c	Fri Jan 09 23:33:09 1998 +0000
@@ -288,8 +288,8 @@
     {
       /* Make a copy of string so that if a GC relocates specs,
 	 `string' will still be valid.  */
-      string = (unsigned char *) alloca (XSTRING (specs)->size + 1);
-      bcopy (XSTRING (specs)->data, string, XSTRING (specs)->size + 1);
+      string = (unsigned char *) alloca (XSTRING (specs)->size_byte + 1);
+      bcopy (XSTRING (specs)->data, string, XSTRING (specs)->size_byte + 1);
     }
   else if (string == 0)
     {
@@ -487,10 +487,10 @@
 	  break;
 
         case 'c':		/* Character */
 	  /* Use message_nolog rather than message1_nolog here,
 	     so that nothing bad happens if callint_message is changed
 	     within Fread_char (by a timer, for example).  */
-	  message_nolog ("%s", callint_message);
+	  message_with_string ("%s", build_string (callint_message), 0);
 	  args[i] = Fread_char ();
 	  message1_nolog ((char *) 0);
 	  /* Passing args[i] directly stimulates compiler bug */
@@ -487,10 +487,10 @@
 
         case 'c':		/* Character */
-	  /* Use message_nolog rather than message1_nolog here,
+	  /* Use message_with_string rather than message1_nolog here,
 	     so that nothing bad happens if callint_message is changed
 	     within Fread_char (by a timer, for example).  */